@@ -530,3 +530,46 @@ class Invite:
         url_code,
     ):
         ...
+
+
+@req('GET')
+class Game:
+
+    def __init__(self):
+        ...
+
+    @staticmethod
+    @req('POST')
+    def create(
+        name,
+        process_name,
+        icon,
+    ):
+        ...
+
+    @staticmethod
+    @req('POST')
+    def update(
+        id,
+        name,
+        icon,
+    ):
+        ...
+
+    @staticmethod
+    @req('POST')
+    def delete(id):
+        ...
+
+    @staticmethod
+    @req('POST')
+    def activity(
+        id,
+        data_type,
+    ):
+        ...
+
+    @staticmethod
+    @req('POST')
+    def deleteActivity():
+        ...
